@@ -85,10 +85,12 @@ from bloom.summary import get_summary_file
 
 from bloom.util import add_global_arguments
 from bloom.util import change_directory
+from bloom.util import disable_git_clone
 from bloom.util import get_rfc_2822_date
 from bloom.util import handle_global_arguments
 from bloom.util import load_url_to_file_handle
 from bloom.util import maybe_continue
+from bloom.util import quiet_git_clone_warning
 
 try:
     import vcstools.__version__
@@ -260,7 +262,7 @@ def generate_ros_distro_diff(track, repository, distro):
     # Update the repository
     repo = release_dict['repositories'][repository]
     if 'tags' not in repo:
-        repo['tages'] = {}
+        repo['tags'] = {}
     repo['tags']['release'] = 'release/%s/{package}/{version}' % distro
     repo['version'] = version
     if 'packages' not in repo:
@@ -486,9 +488,12 @@ _original_version = None
 def start_summary(track):
     global _original_version
     track_dict = get_tracks_dict_raw()['tracks'][track]
-    last_version = track_dict['last_version']  # Actually current version now
-    release_inc = track_dict['release_inc']
-    _original_version = "{0}-{1}".format(last_version, release_inc)
+    if 'last_version' not in track_dict or 'release_inc' not in track_dict:
+        _original_version = 'null'
+    else:
+        last_version = track_dict['last_version']  # Actually current version now
+        release_inc = track_dict['release_inc']
+        _original_version = "{0}-{1}".format(last_version, release_inc)
 
 
 def get_packages():
@@ -636,7 +641,8 @@ def perform_release(repository, track, distro, new_track, interactive, pretend):
             cmd = 'git remote -v'
             info(fmt("@{bf}@!==> @|@!") + str(cmd))
             subprocess.check_call(cmd, shell=True)
-            cmd = 'git push'
+            # Dry run will authenticate, but not push
+            cmd = 'git push --dry-run'
             info(fmt("@{bf}@!==> @|@!") + str(cmd))
             subprocess.check_call(cmd, shell=True)
         except subprocess.CalledProcessError:
@@ -759,6 +765,8 @@ def main(sysargs=None):
 
     try:
         os.environ['BLOOM_TRACK'] = args.track
+        disable_git_clone(True)
+        quiet_git_clone_warning(True)
         perform_release(args.repository, args.track, args.ros_distro,
                         args.new_track, not args.non_interactive, args.pretend)
     except (KeyboardInterrupt, EOFError) as exc:
