@@ -1,5 +1,39 @@
+# Software License Agreement (BSD License)
+#
+# Copyright (c) 2013, Open Source Robotics Foundation, Inc.
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+#  * Redistributions of source code must retain the above copyright
+#    notice, this list of conditions and the following disclaimer.
+#  * Redistributions in binary form must reproduce the above
+#    copyright notice, this list of conditions and the following
+#    disclaimer in the documentation and/or other materials provided
+#    with the distribution.
+#  * Neither the name of Open Source Robotics Foundation, Inc. nor
+#    the names of its contributors may be used to endorse or promote
+#    products derived from this software without specific prior
+#    written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
+
 from __future__ import print_function
 
+from bloom.generators.common import default_fallback_resolver
 
 from bloom.generators.debian import DebianGenerator
 from bloom.generators.debian.generator import generate_substitutions_from_package
@@ -31,6 +65,10 @@ class RosDebianGenerator(DebianGenerator):
         return ret
 
     def get_subs(self, package, debian_distro, releaser_history):
+        def fallback_resolver(key, peer_packages, rosdistro=self.rosdistro):
+            if key in peer_packages:
+                return [rosify_package_name(key, rosdistro)]
+            return default_fallback_resolver(key, peer_packages)
         subs = generate_substitutions_from_package(
             package,
             self.os_name,
@@ -39,7 +77,8 @@ class RosDebianGenerator(DebianGenerator):
             self.install_prefix,
             self.debian_inc,
             [p.name for p in self.packages.values()],
-            releaser_history=releaser_history
+            releaser_history=releaser_history,
+            fallback_resolver=fallback_resolver
         )
         subs['Package'] = rosify_package_name(subs['Package'], self.rosdistro)
         return subs
@@ -73,6 +112,7 @@ def rosify_package_name(name, rosdistro):
 
 
 def get_subs(pkg, os_name, os_version, ros_distro):
+    # No fallback_resolver provided because peer packages not considered.
     subs = generate_substitutions_from_package(
         pkg,
         os_name,
